@@ -54,12 +54,6 @@ function _run_apiv2() {
     ) |& logformatter
 }
 
-function _run_compose() {
-    _bail_if_test_can_be_skipped test/compose
-
-    showrun ./test/compose/test-compose |& logformatter
-}
-
 function _run_compose_v2() {
     _bail_if_test_can_be_skipped test/compose
 
@@ -94,9 +88,6 @@ function _run_bindings() {
     # install ginkgo
     showrun make .install.ginkgo
 
-    # shellcheck disable=SC2155
-    export PATH=$PATH:$GOSRC/hack:$GOSRC/test/tools/build
-
     # if logformatter sees this, it can link directly to failing source lines
     local gitcommit_magic=
     if [[ -n "$GIT_COMMIT" ]]; then
@@ -152,7 +143,8 @@ exec_container() {
     set -x
     # shellcheck disable=SC2154
     exec bin/podman run --rm --privileged --net=host --cgroupns=host \
-        -v `mktemp -d -p /var/tmp`:/tmp:Z \
+        -v `mktemp -d -p /var/tmp`:/var/tmp:Z \
+        --tmpfs /tmp:mode=1777 \
         -v /dev/fuse:/dev/fuse \
         -v "$GOPATH:$GOPATH:Z" \
         --workdir "$GOSRC" \
@@ -168,9 +160,6 @@ function _run_swagger() {
     local envvarsfile
     req_env_vars GCPJSON GCPNAME GCPPROJECT CTR_FQIN
 
-    [[ -x /usr/local/bin/swagger ]] || \
-        die "Expecting swagger binary to be present and executable."
-
     # The filename and bucket depend on the automation context
     #shellcheck disable=SC2154,SC2153
     if [[ -n "$CIRRUS_PR" ]]; then
@@ -419,12 +408,29 @@ dotest() {
         die "Found fallback podman '$fallback_podman' in \$PATH; tests require none, as a guarantee that we're testing the right binary."
     fi
 
+    # Catch invalid "TMPDIR == /tmp" assumptions; PR #19281
+    TMPDIR=$(mktemp --tmpdir -d CI_XXXX)
+    # tmp dir is commonly 1777 to allow all user to read/write
+    chmod 1777 $TMPDIR
+    export TMPDIR
+    fstype=$(findmnt -n -o FSTYPE --target $TMPDIR)
+    if [[ "$fstype" != "tmpfs" ]]; then
+        die "The CI test TMPDIR is not on a tmpfs mount, we need tmpfs to make the tests faster"
+    fi
+
     showrun make ${localremote}${testsuite} PODMAN_SERVER_LOG=$PODMAN_SERVER_LOG \
         |& logformatter
+
+    # FIXME: https://github.com/containers/podman/issues/22642
+    # Cannot delete this due cleanup errors, as the VM is basically
+    # done after this anyway let's not block on this for now.
+    # rm -rf $TMPDIR
+    # unset TMPDIR
 }
 
 _run_machine-linux() {
-    # N/B: Can't use _bail_if_test_can_be_skipped here b/c content isn't under test/
+    _bail_if_test_can_be_skipped pkg/machine/e2e
+
     showrun make localmachine |& logformatter
 }
 
