@@ -207,7 +207,8 @@ var _ = Describe("podman machine init", func() {
 		Expect(err).ToNot(HaveOccurred())
 		_, err = os.CreateTemp(tmpDir, "example")
 		Expect(err).ToNot(HaveOccurred())
-		mount := tmpDir + ":/testmountdir"
+		// Test long target path, see https://github.com/containers/podman/issues/22226
+		mount := tmpDir + ":/very-long-test-mount-dir-path-more-than-thirty-six-bytes"
 		defer func() { _ = utils.GuardedRemoveAll(tmpDir) }()
 
 		name := randomString()
@@ -217,7 +218,7 @@ var _ = Describe("podman machine init", func() {
 		Expect(session).To(Exit(0))
 
 		ssh := sshMachine{}
-		sshSession, err := mb.setName(name).setCmd(ssh.withSSHCommand([]string{"ls /testmountdir"})).run()
+		sshSession, err := mb.setName(name).setCmd(ssh.withSSHCommand([]string{"ls /very-long-test-mount-dir-path-more-than-thirty-six-bytes"})).run()
 		Expect(err).ToNot(HaveOccurred())
 		Expect(sshSession).To(Exit(0))
 		Expect(sshSession.outputToString()).To(ContainSubstring("example"))
@@ -369,6 +370,100 @@ var _ = Describe("podman machine init", func() {
 		Expect(err).ToNot(HaveOccurred())
 		Expect(inspectShouldPass).To(Exit(0))
 	})
+
+	It("machine init with rosetta=true", func() {
+		skipIfVmtype(define.QemuVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.WSLVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.HyperVVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.LibKrun, "Test is only for AppleHv")
+		if runtime.GOARCH != "arm64" {
+			Skip("Test is only for AppleHv with arm64 architecture")
+		}
+
+		i := initMachine{}
+		name := randomString()
+		session, err := mb.setName(name).setCmd(i.withImage(mb.imagePath)).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(session).To(Exit(0))
+
+		s := startMachine{}
+		ssession, err := mb.setCmd(s).setTimeout(time.Minute * 10).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(ssession).Should(Exit(0))
+
+		inspect := new(inspectMachine)
+		inspect = inspect.withFormat("{{.Rosetta}}")
+		inspectSession, err := mb.setName(name).setCmd(inspect).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(inspectSession).To(Exit(0))
+		Expect(inspectSession.outputToString()).To(Equal("true"))
+
+		mnt := sshMachine{}
+		mntSession, err := mb.setName(name).setCmd(mnt.withSSHCommand([]string{"ls -d /mnt/rosetta"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(mntSession).To(Exit(0))
+		Expect(mntSession.outputToString()).To(ContainSubstring("/mnt/rosetta"))
+
+		proc := sshMachine{}
+		procSession, err := mb.setName(name).setCmd(proc.withSSHCommand([]string{"ls -d /proc/sys/fs/binfmt_misc/rosetta"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(procSession).To(Exit(0))
+		Expect(procSession.outputToString()).To(ContainSubstring("/proc/sys/fs/binfmt_misc/rosetta"))
+
+		proc2 := sshMachine{}
+		proc2Session, err := mb.setName(name).setCmd(proc2.withSSHCommand([]string{"ls -d /proc/sys/fs/binfmt_misc/qemu-x86_64"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(proc2Session.ExitCode()).To(Equal(2))
+	})
+
+	It("machine init with rosetta=false", func() {
+		skipIfVmtype(define.QemuVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.WSLVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.HyperVVirt, "Test is only for AppleHv")
+		skipIfVmtype(define.LibKrun, "Test is only for AppleHv")
+		if runtime.GOARCH != "arm64" {
+			Skip("Test is only for AppleHv with arm64 architecture")
+		}
+		configDir := filepath.Join(testDir, ".config", "containers")
+		err := os.MkdirAll(configDir, 0755)
+		Expect(err).ToNot(HaveOccurred())
+
+		err = os.WriteFile(filepath.Join(configDir, "containers.conf"), rosettaConfig, 0644)
+		Expect(err).ToNot(HaveOccurred())
+
+		i := initMachine{}
+		name := randomString()
+		session, err := mb.setName(name).setCmd(i.withImage(mb.imagePath)).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(session).To(Exit(0))
+
+		s := startMachine{}
+		ssession, err := mb.setCmd(s).setTimeout(time.Minute * 10).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(ssession).Should(Exit(0))
+
+		inspect := new(inspectMachine)
+		inspect = inspect.withFormat("{{.Rosetta}}")
+		inspectSession, err := mb.setName(name).setCmd(inspect).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(inspectSession).To(Exit(0))
+		Expect(inspectSession.outputToString()).To(Equal("false"))
+
+		mnt := sshMachine{}
+		mntSession, err := mb.setName(name).setCmd(mnt.withSSHCommand([]string{"ls -d /mnt/rosetta"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(mntSession.ExitCode()).To(Equal(2))
+
+		proc := sshMachine{}
+		procSession, err := mb.setName(name).setCmd(proc.withSSHCommand([]string{"ls -d /proc/sys/fs/binfmt_misc/rosetta"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(procSession.ExitCode()).To(Equal(2))
+
+		proc2 := sshMachine{}
+		proc2Session, err := mb.setName(name).setCmd(proc2.withSSHCommand([]string{"ls -d /proc/sys/fs/binfmt_misc/qemu-x86_64"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(proc2Session.outputToString()).To(ContainSubstring("/proc/sys/fs/binfmt_misc/qemu-x86_64"))
+	})
 })
 
 var p4Config = []byte(`{
@@ -454,3 +549,8 @@ var p4Config = []byte(`{
  "LastUp": "0001-01-01T00:00:00Z"
 }
 `)
+
+var rosettaConfig = []byte(`
+[machine]
+rosetta=false
+`)
